==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/7d/7d7877dbc2ecf144f1e914e43445c46d.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fpoe_kaernten_theme_full_final_v2/assets/fb-white.png */
class __TwigTemplate_9fb7bb1a3f77632282de61b7a1675d19 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000#\000\000\000b\000\000\000sBIT|d\000\000
IDATHKT@(A*JIR@󞉙r9;?nwߛi)bi5}(߶S@%H\000\">`2ְl{ d\000~k`
BA_`DX!s ]@\tuo)2U2@KP*'NR8BV@`|{KNy5~32Mb½#.m\000J^[?_H.rYfXg}Rٻ\$\\#\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fpoe_kaernten_theme_full_final_v2/assets/fb-white.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/assets/fb-white.png", "/var/www/mautic-ktn/themes/fpoe_kaernten_theme_full_final_v2/assets/fb-white.png");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/7d/7d7877dbc2ecf144f1e914e43445c46d.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fpoe_kaernten_theme_full_final_v2/assets/fb-white.png */
class __TwigTemplate_9fb7bb1a3f77632282de61b7a1675d19 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000#\000\000\000b\000\000\000sBIT|d\000\000
IDATHKT@(A*JIR@󞉙r9;?nwߛi)bi5}(߶S@%H\000\">`2ְl{ d\000~k`
BA_`DX!s ]@\tuo)2U2@KP*'NR8BV@`|{KNy5~32Mb½#.m\000J^[?_H.rYfXg}Rٻ\$\\#\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fpoe_kaernten_theme_full_final_v2/assets/fb-white.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/assets/fb-white.png", "/var/www/html/mauticGIT-Test/themes/fpoe_kaernten_theme_full_final_v2/assets/fb-white.png");
    }
}
